==> gravestones-1.2.1%2B1.21.8%2BA-sources.jar: net/pneumono/gravestones/content/AestheticGravestoneBlockEntityRenderer.java <==
package net.pneumono.gravestones.content;

import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_2190;
import net.minecraft.class_2484;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_8242;
import net.minecraft.class_836;
import net.minecraft.class_9296;
import net.minecraft.class_9334;
import net.pneumono.gravestones.block.AestheticGravestoneBlockEntity;
import org.jetbrains.annotations.Nullable;
//?}

//? if >=1.21.9 {
/*public class AestheticGravestoneBlockEntityRenderer extends AbstractGravestoneBlockEntityRenderer<AestheticGravestoneBlockEntity, AestheticGravestoneBlockEntityRenderer.AestheticRenderState> {
*///?} else {
public class AestheticGravestoneBlockEntityRenderer extends AbstractGravestoneBlockEntityRenderer<AestheticGravestoneBlockEntity> {
//?}
    public AestheticGravestoneBlockEntityRenderer(class_5614.class_5615 ctx) {
        super(ctx);
    }

    @Override
    public class_8242 getSignText(AestheticGravestoneBlockEntity entity) {
        return entity.getText();
    }

    @Override
    //? if >=1.21.9 {
    /*public void renderHead(AestheticRenderState info, MatrixStack matrices, OrderedRenderCommandQueue queue, float yaw, float pitch) {
    *///?} else {
    public void renderHead(AestheticGravestoneBlockEntity info, class_4587 matrices, class_4597 vertexConsumers, float yaw, float pitch, int light) {
    //?}
        class_1799 headStack = info.getHeadStack();
        if (headStack.method_7960()) return;

        if (
                !(headStack.method_7909() instanceof class_1747 blockItem) ||
                !(blockItem.method_7711() instanceof class_2190 skullBlock)
        ) return;

        class_2484.class_2485 type = skullBlock.method_9327();

        //? if >=1.21.9 {
        /*ProfileComponent profileComponent = headStack.get(DataComponentTypes.PROFILE);
        RenderLayer layer;
        if (profileComponent != null) {
            layer = this.skinCache.get(profileComponent).getRenderLayer();
        } else {
            layer = SkullBlockEntityRenderer.getCutoutRenderLayer(type, null);
        }

        renderHeadModel(
                info,
                matrices,
                this.models.apply(type),
                queue,
                layer,
                yaw,
                pitch
        );
        *///?} else {
        class_4588 vertexConsumer = vertexConsumers.getBuffer(
                class_836.method_65832(type, getStackProfile(headStack))
        );
        renderHeadModel(matrices, this.models.apply(type), vertexConsumer, yaw, pitch, light);
        //?}
    }

    //? if >=1.20.6 {
    @Nullable
    private static class_9296 getStackProfile(class_1799 stack) {
        return stack.method_58694(class_9334.field_49617);
    }
    //?} else {
    /*@Nullable
    private static GameProfile getStackProfile(ItemStack stack) {
        GameProfile gameProfile = null;
        NbtCompound nbtCompound = stack.getNbt();
        if (nbtCompound != null && !nbtCompound.isEmpty()) {
            if (nbtCompound.contains("SkullOwner", NbtElement.COMPOUND_TYPE)) {
                gameProfile = NbtHelper.toGameProfile(nbtCompound.getCompound("SkullOwner"));
            } else if (nbtCompound.contains("SkullOwner", NbtElement.STRING_TYPE) && !Util.isBlank(nbtCompound.getString("SkullOwner"))) {
                gameProfile = new GameProfile(Util.NIL_UUID, nbtCompound.getString("SkullOwner"));
            }
        }

        return gameProfile;
    }
    *///?}

    //? if >=1.21.9 {
    /*@Override
    public AestheticRenderState createRenderState() {
        return new AestheticRenderState();
    }

    @Override
    public void updateRenderState(AestheticGravestoneBlockEntity entity, AestheticRenderState state, float tickProgress, Vec3d cameraPos, ModelCommandRenderer.@Nullable CrumblingOverlayCommand crumblingOverlay) {
        super.updateRenderState(entity, state, tickProgress, cameraPos, crumblingOverlay);
        state.headStack = entity.getHeadStack();
    }

    public static class AestheticRenderState extends RenderState {
        public ItemStack headStack;

        public ItemStack getHeadStack() {
            return headStack;
        }
    }
    *///?}
}

==> gravestones-1.2.3%2B1.20.1%2BA-sources.jar: net/pneumono/gravestones/content/AestheticGravestoneBlockEntityRenderer.java <==
package net.pneumono.gravestones.content;

import net.minecraft.class_156;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_2190;
import net.minecraft.class_2484;
import net.minecraft.class_2487;
import net.minecraft.class_2512;
import net.minecraft.class_2520;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_8242;
import net.minecraft.class_836;
import net.pneumono.gravestones.block.AestheticGravestoneBlockEntity;
import org.jetbrains.annotations.Nullable;
//?}

//? if >=1.20.6 {
/*import net.minecraft.component.DataComponentTypes;
import net.minecraft.component.type.ProfileComponent;
*///?} else {
import com.mojang.authlib.GameProfile;

//? if >=1.21.9 {
/*public class AestheticGravestoneBlockEntityRenderer extends AbstractGravestoneBlockEntityRenderer<AestheticGravestoneBlockEntity, AestheticGravestoneBlockEntityRenderer.AestheticRenderState> {
*///?} else {
public class AestheticGravestoneBlockEntityRenderer extends AbstractGravestoneBlockEntityRenderer<AestheticGravestoneBlockEntity> {
//?}
    public AestheticGravestoneBlockEntityRenderer(class_5614.class_5615 ctx) {
        super(ctx);
    }

    @Override
    public class_8242 getSignText(AestheticGravestoneBlockEntity entity) {
        return entity.getText();
    }

    @Override
    //? if >=1.21.9 {
    /*public void renderHead(AestheticRenderState info, MatrixStack matrices, OrderedRenderCommandQueue queue, float yaw, float pitch) {
    *///?} else {
    public void renderHead(AestheticGravestoneBlockEntity info, class_4587 matrices, class_4597 vertexConsumers, float yaw, float pitch, int light) {
    //?}
        class_1799 headStack = info.getHeadStack();
        if (headStack.method_7960()) return;

        if (
                !(headStack.method_7909() instanceof class_1747 blockItem) ||
                !(blockItem.method_7711() instanceof class_2190 skullBlock)
        ) return;

        class_2484.class_2485 type = skullBlock.method_9327();

        //? if >=1.21.9 {
        /*ProfileComponent profileComponent = headStack.get(DataComponentTypes.PROFILE);
        RenderLayer layer;
        if (profileComponent != null) {
            layer = this.skinCache.get(profileComponent).getRenderLayer();
        } else {
            layer = SkullBlockEntityRenderer.getCutoutRenderLayer(type, null);
        }

        renderHeadModel(
                info,
                matrices,
                this.models.apply(type),
                queue,
                layer,
                yaw,
                pitch
        );
        *///?} else {
        class_4588 vertexConsumer = vertexConsumers.getBuffer(
                class_836.method_3578(type, getStackProfile(headStack))
        );
        renderHeadModel(matrices, this.models.apply(type), vertexConsumer, yaw, pitch, light);
        //?}
    }

    //? if >=1.20.6 {
    /*@Nullable
    private static ProfileComponent getStackProfile(ItemStack stack) {
        return stack.get(DataComponentTypes.PROFILE);
    }
    *///?} else {
    @Nullable
    private static GameProfile getStackProfile(class_1799 stack) {
        GameProfile gameProfile = null;
        class_2487 nbtCompound = stack.method_7969();
        if (nbtCompound != null && !nbtCompound.method_33133()) {
            if (nbtCompound.method_10573("SkullOwner", class_2520.field_33260)) {
                gameProfile = class_2512.method_10683(nbtCompound.method_10562("SkullOwner"));
            } else if (nbtCompound.method_10573("SkullOwner", class_2520.field_33258) && !class_156.method_51894(nbtCompound.method_10558("SkullOwner"))) {
                gameProfile = new GameProfile(class_156.field_25140, nbtCompound.method_10558("SkullOwner"));
            }
        }

        return gameProfile;
    }
    //?}

    //? if >=1.21.9 {
    /*@Override
    public AestheticRenderState createRenderState() {
        return new AestheticRenderState();
    }

    @Override
    public void updateRenderState(AestheticGravestoneBlockEntity entity, AestheticRenderState state, float tickProgress, Vec3d cameraPos, ModelCommandRenderer.@Nullable CrumblingOverlayCommand crumblingOverlay) {
        super.updateRenderState(entity, state, tickProgress, cameraPos, crumblingOverlay);
        state.headStack = entity.getHeadStack();
    }

    public static class AestheticRenderState extends RenderState {
        public ItemStack headStack;

        public ItemStack getHeadStack() {
            return headStack;
        }
    }
    *///?}
}
